===================
Linux Remote Server
===================
This is an Server Package for `LinuxRemote <https://play.google.com/store/apps/details?id=org.linuxremote.app>`_ Android APP.

See `Promo video <http://www.youtube.com/watch?v=B0hCD782UfI>`_ for more information.


Steps to Install
----------------
* Using pip package installer of python 2 or 3
* ``$ sudo pip3 install linux-remote``
* ``$ sudo linux-remote-setup install``

Steps to Upgrade
----------------
* ``$ sudo pip3 install --upgrade linux-remote``
* ``$ sudo linux-remote-setup install``

Steps to Uninstall
------------------
* ``$ sudo linux-remote-setup uninstall``
* ``$ sudo pip3 uninstall linux-remote``
